@@ -12,6 +12,7 @@
 #
 ##############################################################################
 
+import cPickle
 import math
 import os
 import time
@@ -256,17 +257,80 @@ class DateTimeTests(unittest.TestCase):
         from cPickle import dumps, loads
         self.assertEqual(loads(dumps(dt)).strftime('%Y'), '2001')
 
-    def test___setstate___without_micros(self):
-        ISO = '2001-10-10T00:00:00+02:00'
-        dt = DateTime(ISO)
-        micros = dt._micros
-        dt._millis = dt._micros / 1000
-        del dt._micros
-        state = dt.__dict__
+    def test_pickle(self):
+        dt = DateTime()
+        data = cPickle.dumps(dt, 1)
+        new = cPickle.loads(data)
+        self.assertEqual(dt.__dict__, new.__dict__)
 
-        dt1 = DateTime()
-        dt1.__setstate__(state)
-        self.assertEqual(dt1._micros, micros)
+    def test_pickle_with_tz(self):
+        dt = DateTime('2002/5/2 8:00am GMT+8')
+        data = cPickle.dumps(dt, 1)
+        new = cPickle.loads(data)
+        self.assertEqual(dt.__dict__, new.__dict__)
+
+    def test_pickle_with_micros(self):
+        dt = DateTime('2002/5/2 8:00:14.123 GMT+8')
+        data = cPickle.dumps(dt, 1)
+        new = cPickle.loads(data)
+        self.assertEqual(dt.__dict__, new.__dict__)
+
+    def test_pickle_new(self):
+        dt = DateTime('2002/5/2 8:00am')
+        data = ('ccopy_reg\n_reconstructor\nq\x01(cDateTime.DateTime\n'
+            'DateTime\nq\x02c__builtin__\nobject\nq\x03NtRq\x04(GA\xcehj'
+            '\xf0\x00\x00\x00I01\nU\x05GMT+2q\x05tb.')
+        new = cPickle.loads(data)
+        self._compare(dt, new)
+
+    def test_pickle_new_with_tz(self):
+        dt = DateTime('2002/5/2 8:00am GMT+8')
+        data = ('ccopy_reg\n_reconstructor\nq\x01(cDateTime.DateTime\n'
+            'DateTime\nq\x02c__builtin__\nobject\nq\x03NtRq\x04(GA\xceh@'
+            '\xc0\x00\x00\x00I00\nU\x05GMT+8q\x05tb.')
+        new = cPickle.loads(data)
+        self._compare(dt, new)
+
+    def test_pickle_new_with_micros(self):
+        dt = DateTime('2002/5/2 8:00:14.123 GMT+8')
+        data = ('ccopy_reg\n_reconstructor\nq\x01(cDateTime.DateTime\n'
+            'DateTime\nq\x02c__builtin__\nobject\nq\x03NtRq\x04(GA\xceh@'
+            '\xc7\x0f\xbewI00\nU\x05GMT+8q\x05tb.')
+        new = cPickle.loads(data)
+        self._compare(dt, new)
+
+    def test_pickle_old(self):
+        dt = DateTime('2002/5/2 8:00am GMT+0')
+        data = ('(cDateTime.DateTime\nDateTime\nq\x01Noq\x02}q\x03(U\x05_amonq'
+            '\x04U\x03Mayq\x05U\x05_adayq\x06U\x03Thuq\x07U\x05_pmonq\x08h'
+            '\x05U\x05_hourq\tK\x08U\x05_fmonq\nh\x05U\x05_pdayq\x0bU\x04T'
+            'hu.q\x0cU\x05_fdayq\rU\x08Thursdayq\x0eU\x03_pmq\x0fU\x02amq'
+            '\x10U\x02_tq\x11GA\xcehy\x00\x00\x00\x00U\x07_minuteq\x12K\x00U'
+            '\x07_microsq\x13L1020326400000000L\nU\x02_dq\x14G@\xe2\x12j\xaa'
+            '\xaa\xaa\xabU\x07_secondq\x15G\x00\x00\x00\x00\x00\x00\x00\x00U'
+            '\x03_tzq\x16U\x05GMT+0q\x17U\x06_monthq\x18K\x05U'
+            '\x0f_timezone_naiveq\x19I00\nU\x04_dayq\x1aK\x02U\x05_yearq'
+            '\x1bM\xd2\x07U\x08_nearsecq\x1cG\x00\x00\x00\x00\x00\x00\x00'
+            '\x00U\x07_pmhourq\x1dK\x08U\n_dayoffsetq\x1eK\x04U\x04timeq'
+            '\x1fG?\xd5UUUV\x00\x00ub.')
+        new = cPickle.loads(data)
+        self.assertEqual(dt.__dict__, new.__dict__)
+
+    def test_pickle_old_without_micros(self):
+        dt = DateTime('2002/5/2 8:00am GMT+0')
+        data = ('(cDateTime.DateTime\nDateTime\nq\x01Noq\x02}q\x03(U\x05_amonq'
+            '\x04U\x03Mayq\x05U\x05_adayq\x06U\x03Thuq\x07U\x05_pmonq\x08h'
+            '\x05U\x05_hourq\tK\x08U\x05_fmonq\nh\x05U\x05_pdayq\x0bU'
+            '\x04Thu.q\x0cU\x05_fdayq\rU\x08Thursdayq\x0eU\x03_pmq\x0fU'
+            '\x02amq\x10U\x02_tq\x11GA\xcehy\x00\x00\x00\x00U\x07_minuteq'
+            '\x12K\x00U\x02_dq\x13G@\xe2\x12j\xaa\xaa\xaa\xabU\x07_secondq'
+            '\x14G\x00\x00\x00\x00\x00\x00\x00\x00U\x03_tzq\x15U\x05GMT+0q'
+            '\x16U\x06_monthq\x17K\x05U\x0f_timezone_naiveq\x18I00\nU'
+            '\x04_dayq\x19K\x02U\x05_yearq\x1aM\xd2\x07U\x08_nearsecq'
+            '\x1bG\x00\x00\x00\x00\x00\x00\x00\x00U\x07_pmhourq\x1cK\x08U'
+            '\n_dayoffsetq\x1dK\x04U\x04timeq\x1eG?\xd5UUUV\x00\x00ub.')
+        new = cPickle.loads(data)
+        self.assertEqual(dt.__dict__, new.__dict__)
 
     def testTZ2(self):
         # Time zone manipulation test 2
@@ -437,18 +501,12 @@ class DateTimeTests(unittest.TestCase):
 
     def testJulianWeek(self):
         # Check JulianDayWeek function
-        try:
-            import gzip
-        except ImportError:
-            print "Warning: testJulianWeek disabled: module gzip not found"
-            return 0
-
-        fn = os.path.join(DATADIR, 'julian_testdata.txt.gz')
-        lines = gzip.GzipFile(fn).readlines()
-
+        fn = os.path.join(DATADIR, 'julian_testdata.txt')
+        with open(fn, 'r') as fd:
+            lines = fd.readlines()
         for line in lines:
             d = DateTime(line[:10])
-            result_from_mx=tuple(map(int, line[12:-2].split(',')))
+            result_from_mx = tuple(map(int, line[12:-2].split(',')))
             self.assertEqual(result_from_mx[1], d.week())
 
     def testCopyConstructor(self):
@@ -501,22 +559,22 @@ class DateTimeTests(unittest.TestCase):
         self.assertEqual(int(times[0]), dt.h_24())
         self.assertEqual(int(times[1]), dt.minute())
         self.assertEqual(int(times[2]), int(dt.second()))
-        self.assertEqual(dts[5], "%+03d%02d" % divmod( (-offset/60), 60) )
+        self.assertEqual(dts[5], "%+03d%02d" % divmod((-offset / 60), 60))
 
     def testInternationalDateformat(self):
-        for year in range(1990, 2020):
-            for month in range (1, 13):
-                for day in range(1, 32):
+        for year in (1990, 2001, 2020):
+            for month in (1, 12):
+                for day in (1, 12, 28, 31):
                     try:
-                        d_us = DateTime("%d/%d/%d" % (year,month,day))
-                    except:
+                        d_us = DateTime("%d/%d/%d" % (year, month, day))
+                    except Exception:
                         continue
 
-                    d_int = DateTime("%d.%d.%d" % (day,month,year),
+                    d_int = DateTime("%d.%d.%d" % (day, month, year),
                                      datefmt="international")
                     self.assertEqual(d_us, d_int)
 
-                    d_int = DateTime("%d/%d/%d" % (day,month,year),
+                    d_int = DateTime("%d/%d/%d" % (day, month, year),
                                      datefmt="international")
                     self.assertEqual(d_us, d_int)
 
