@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -346,6 +346,54 @@ class TestConfig(LoggingTestBase):
         self.assertEqual(handler.fromaddr, "zlog-user@example.com")
         self.assertEqual(handler.level, logging.FATAL)
 
+    def test_with_email_notifier_with_credentials(self):
+        try:
+            logger = self.check_simple_logger("<eventlog>\n"
+                                              "  <email-notifier>\n"
+                                              "    to sysadmin@example.com\n"
+                                              "    from zlog-user@example.com\n"
+                                              "    level fatal\n"
+                                              "    smtp-username john\n"
+                                              "    smtp-password johnpw\n"
+                                              "  </email-notifier>\n"
+                                              "</eventlog>")
+        except ValueError:
+            if sys.version_info >= (2, 6):
+                # For python 2.6 no ValueError must be raised.
+                raise
+        else:
+            # This path must only be reached with python >=2.6
+            self.assert_(sys.version_info >= (2, 6))
+            handler = logger.handlers[0]
+            self.assertEqual(handler.toaddrs, ["sysadmin@example.com"])
+            self.assertEqual(handler.fromaddr, "zlog-user@example.com")
+            self.assertEqual(handler.fromaddr, "zlog-user@example.com")
+            self.assertEqual(handler.level, logging.FATAL)
+            self.assertEqual(handler.username, 'john')
+            self.assertEqual(handler.password, 'johnpw')
+
+    def test_with_email_notifier_with_invalid_credentials(self):
+        self.assertRaises(ValueError,
+                          self.check_simple_logger,
+                          "<eventlog>\n"
+                          "  <email-notifier>\n"
+                          "    to sysadmin@example.com\n"
+                          "    from zlog-user@example.com\n"
+                          "    level fatal\n"
+                          "    smtp-username john\n"
+                          "  </email-notifier>\n"
+                          "</eventlog>")
+        self.assertRaises(ValueError,
+                          self.check_simple_logger,
+                          "<eventlog>\n"
+                          "  <email-notifier>\n"
+                          "    to sysadmin@example.com\n"
+                          "    from zlog-user@example.com\n"
+                          "    level fatal\n"
+                          "    smtp-password john\n"
+                          "  </email-notifier>\n"
+                          "</eventlog>")
+
     def check_simple_logger(self, text, level=logging.INFO):
         conf = self.get_config(text)
         self.assert_(conf.eventlog is not None)
@@ -489,6 +537,23 @@ class TestReopeningLogfiles(TestReopeningLogfilesBase):
                 logger.removeHandler(handler)
                 handler.close()
 
+    def test_filehandler_reopen_thread_safety(self):
+        # The reopen method needs to do locking to avoid a race condition
+        # with emit calls. For simplicity we replace the "acquire" and
+        # "release" methods with dummies that record calls to them.
+
+        fn = self.mktemp()
+        h = self.handler_factory(fn)
+
+        calls = []
+        h.acquire = lambda: calls.append("acquire")
+        h.release = lambda: calls.append("release")
+
+        h.reopen()
+        h.close()
+
+        self.assertEqual(calls, ["acquire", "release"])
+
 
 class TestReopeningRotatingLogfiles(TestReopeningLogfilesBase):
 
