@@ -13,9 +13,8 @@
 ##############################################################################
 
 import os
-import sys
 import time
-import random
+import socket
 import asyncore
 import threading
 import logging
@@ -23,7 +22,7 @@ import logging
 import ZEO.ServerStub
 from ZEO.ClientStorage import ClientStorage
 from ZEO.Exceptions import ClientDisconnected
-from ZEO.zrpc.marshal import Marshaller
+from ZEO.zrpc.marshal import encode
 from ZEO.tests import forker
 
 from ZODB.DB import DB
@@ -474,7 +473,7 @@ class ConnectionTests(CommonSetupTearDown):
         class Hack:
             pass
 
-        msg = Marshaller().encode(1, 0, "foo", (Hack(),))
+        msg = encode(1, 0, "foo", (Hack(),))
         self._bad_message(msg)
         del Hack
 
@@ -592,7 +591,7 @@ class InvqTests(CommonSetupTearDown):
     invq = 3
 
     def checkQuickVerificationWith2Clients(self):
-        perstorage = self.openClientStorage(cache="test")
+        perstorage = self.openClientStorage(cache="test", cache_size=4000)
         self.assertEqual(perstorage.verify_result, "empty cache")
 
         self._storage = self.openClientStorage()
@@ -610,14 +609,19 @@ class InvqTests(CommonSetupTearDown):
         revid2 = self._dostore(oid2)
         revid2 = self._dostore(oid2, revid2)
 
-        # sync() is needed to prevent invalidation for oid from arriving
-        # in the middle of the load() call.
-        perstorage.sync()
         perstorage.load(oid, '')
         perstorage.close()
 
+        forker.wait_until(lambda : os.path.exists('test-1.zec'))
+
         revid = self._dostore(oid, revid)
+
         perstorage = self.openClientStorage(cache="test")
+
+        forker.wait_until(
+            (lambda : perstorage.verify_result == "quick verification"),
+            onfail=(lambda : None))
+
         self.assertEqual(perstorage.verify_result, "quick verification")
         self.assertEqual(perstorage._server._last_invals,
                          (revid, [oid]))
@@ -932,6 +936,7 @@ class ReconnectionTests(CommonSetupTearDown):
         self.shutdownServer()
         logging.info("checkReconnection(): About to restart server")
         self.startServer(create=0)
+        forker.wait_until('reconnect', self._storage.is_connected)
         oid = self._storage.new_oid()
         obj = MinPO(12)
         while 1:
@@ -987,6 +992,16 @@ class TimeoutTests(CommonSetupTearDown):
         storage.tpc_vote(txn)
         time.sleep(2)
         self.assertRaises(ClientDisconnected, storage.tpc_finish, txn)
+
+        # Make sure it's logged as CRITICAL
+        for line in open("server-%s.log" % self.addr[0][1]):
+            if (('Transaction timeout after' in line) and
+                ('CRITICAL ZEO.StorageServer' in line)
+                ):
+                break
+        else:
+            self.assert_(False, 'bad logging')
+
         storage.close()
 
     def checkTimeoutOnAbort(self):
@@ -1093,7 +1108,8 @@ class TimeoutTests(CommonSetupTearDown):
         self.assertRaises(ConflictError, storage.tpc_vote, t)
         # Even aborting won't help.
         storage.tpc_abort(t)
-        storage.tpc_finish(t)
+        self.assertRaises(ZODB.POSException.StorageTransactionError,
+                          storage.tpc_finish, t)
         # Try again.
         obj.value = 10
         t = Transaction()
@@ -1103,7 +1119,7 @@ class TimeoutTests(CommonSetupTearDown):
         self.assertRaises(ConflictError, storage.tpc_vote, t)
         # Abort this one and try a transaction that should succeed.
         storage.tpc_abort(t)
-        storage.tpc_finish(t)
+        
         # Now do a store.
         obj.value = 11
         t = Transaction()
@@ -1190,3 +1206,18 @@ class MSTThread(threading.Thread):
                 c.close()
             except:
                 pass
+
+# Run IPv6 tests if V6 sockets are supported
+try:
+    socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
+except (socket.error, AttributeError):
+    pass
+else:
+    class V6Setup:
+        def _getAddr(self):
+            return '::1', forker.get_port(self)
+
+    _g = globals()
+    for name, value in _g.items():
+        if isinstance(value, type) and issubclass(value, CommonSetupTearDown):
+            _g[name+"V6"] = type(name+"V6", (V6Setup, value), {})
