@@ -14,7 +14,7 @@
 static char cPersistence_doc_string[] =
   "Defines Persistent mixin class for persistent objects.\n"
   "\n"
-  "$Id: cPersistence.c 113733 2010-06-21 15:32:58Z ctheune $\n";
+  "$Id: cPersistence.c 116138 2010-09-02 13:55:38Z jim $\n";
 
 #include "cPersistence.h"
 #include "structmember.h"
@@ -223,6 +223,29 @@ changed(cPersistentObject *self)
   return 0;
 }
 
+static int
+readCurrent(cPersistentObject *self)
+{
+  if ((self->state == cPersistent_UPTODATE_STATE ||
+       self->state == cPersistent_STICKY_STATE)
+      && self->jar && self->oid)
+    {
+      static PyObject *s_readCurrent=NULL;
+      PyObject *r;
+
+      if (s_readCurrent == NULL)
+        s_readCurrent = PyString_InternFromString("readCurrent");
+
+      r = PyObject_CallMethodObjArgs(self->jar, s_readCurrent, self, NULL);
+      if (r == NULL)
+        return -1;
+
+      Py_DECREF(r);
+    }
+
+  return 0;
+}
+
 static PyObject *
 Per__p_deactivate(cPersistentObject *self)
 {
@@ -1235,6 +1258,12 @@ Per_setstate(cPersistentObject *self)
 static PyObject *
 simple_new(PyObject *self, PyObject *type_object)
 {
+  if (!PyType_Check(type_object))
+    {
+      PyErr_SetString(PyExc_TypeError,
+                      "simple_new argument must be a type object.");
+      return NULL;
+    }
   return PyType_GenericNew((PyTypeObject *)type_object, NULL, NULL);
 }
 
@@ -1256,9 +1285,10 @@ truecPersistenceCAPI = {
   accessed,
   ghostify,
   (intfunctionwithpythonarg)Per_setstate,
-  NULL /* The percachedel slot is initialized in cPickleCache.c when
+  NULL, /* The percachedel slot is initialized in cPickleCache.c when
           the module is loaded.  It uses a function in a different
           shared library. */
+  readCurrent
 };
 
 void
