@@ -13,72 +13,69 @@
 ##############################################################################
 
 import os
-from setuptools import setup, find_packages, Extension
+import sys
+from setuptools import setup, find_packages
+
+additional_install_requires = []
+
+if sys.platform[:3].lower() == "win":
+    additional_install_requires += ['nt_svcutils']
+
 
 setup(name='Zope2',
-    version='2.12.26',
-    url='http://www.zope.org',
+    version='2.13.21',
+    url='http://zope2.zope.org',
     license='ZPL 2.1',
     description='Zope2 application server / web framework',
     author='Zope Foundation and Contributors',
     author_email='zope-dev@zope.org',
     long_description=file("README.txt").read() + "\n" +
                      file(os.path.join("doc", "CHANGES.rst")).read(),
-
+    classifiers=[
+        'Development Status :: 6 - Mature',
+        "Environment :: Web Environment",
+        "Framework :: Zope2",
+        "License :: OSI Approved :: Zope Public License",
+        "Operating System :: OS Independent",
+        "Programming Language :: Python",
+        "Programming Language :: Python :: 2 :: Only",
+        "Programming Language :: Python :: 2.6",
+        "Programming Language :: Python :: 2.7",
+        "Programming Language :: Python :: Implementation :: CPython",
+    ],
     packages=find_packages('src'),
     namespace_packages=['Products', 'Shared', 'Shared.DC'],
     package_dir={'': 'src'},
-
-    ext_modules=[
-
-      # AccessControl
-      Extension(
-            name='AccessControl.cAccessControl',
-            include_dirs=['include', 'src'],
-            sources=['src/AccessControl/cAccessControl.c'],
-            depends=['include/ExtensionClass/ExtensionClass.h',
-                     'include/Acquisition/Acquisition.h']),
-
-      # DocumentTemplate
-      Extension(
-            name='DocumentTemplate.cDocumentTemplate',
-            include_dirs=['include', 'src'],
-            sources=['src/DocumentTemplate/cDocumentTemplate.c'],
-            depends=['include/ExtensionClass/ExtensionClass.h']),
-
-      # indexes
-      Extension(
-            name='Products.ZCTextIndex.stopper',
-            sources=['src/Products/ZCTextIndex/stopper.c']),
-      Extension(
-            name='Products.ZCTextIndex.okascore',
-            sources=['src/Products/ZCTextIndex/okascore.c']),
-
-    ],
-
     install_requires=[
+      'AccessControl>=2.13.2',
       'Acquisition',
       'DateTime',
+      'DocumentTemplate',
       'ExtensionClass',
       'Missing',
       'MultiMapping',
       'Persistence',
-      'Products.ZSQLMethods',
+      'Products.OFSP >= 2.13.2',
+      'Products.ZCatalog',
+      'Products.ZCTextIndex',
       'Record',
       'RestrictedPython',
-      'ThreadLock',
       'ZConfig',
       'ZODB3',
       'ZopeUndo',
       'docutils',
-      'five.formlib',
       'initgroups',
       'pytz',
       'setuptools',
       'tempstorage',
       'transaction',
       'zdaemon',
+      'zExceptions',
       'zLOG',
+      'zope.browser',
+      'zope.browsermenu',
+      'zope.browserpage',
+      'zope.browserresource',
       'zope.component',
       'zope.configuration',
       'zope.container',
@@ -92,38 +89,45 @@ setup(name='Zope2',
       'zope.interface',
       'zope.lifecycleevent',
       'zope.location',
-      'zope.mkzeoinstance',
       'zope.pagetemplate',
       'zope.processlifetime',
       'zope.proxy',
+      'zope.ptresource',
       'zope.publisher',
       'zope.schema',
       'zope.security',
-      'zope.sendmail<3.7.0',
+      'zope.sendmail',
       'zope.sequencesort',
       'zope.site',
       'zope.size',
       'zope.structuredtext',
       'zope.tal',
-      'zope.tales',
-      'zope.testbrowser [zope-functional-testing]',
+      'zope.tales >= 3.5.0',
+      'zope.testbrowser',
       'zope.testing',
       'zope.traversing',
       'zope.viewlet',
-      'zope.app.publication',
-      'zope.app.publisher',
-      'zope.app.schema',
-    ],
+      # BBB optional dependencies to be removed in Zope 2.14
+      'Products.BTreeFolder2',
+      'Products.ExternalMethod',
+      'Products.MailHost',
+      'Products.MIMETools',
+      'Products.PythonScripts',
+      'Products.StandardCacheManagers',
+    ] + additional_install_requires,
 
     include_package_data=True,
     zip_safe=False,
     entry_points={
+       'paste.app_factory': [
+          'main=Zope2.Startup.run:make_wsgi_app',
+       ],
        'console_scripts': [
-          'mkzeoinstance=zope.mkzeoinstance:main',
           'mkzopeinstance=Zope2.utilities.mkzopeinstance:main',
           'runzope=Zope2.Startup.run:run',
           'zopectl=Zope2.Startup.zopectl:run',
           'zpasswd=Zope2.utilities.zpasswd:main',
+          'addzope2user=Zope2.utilities.adduser:main',
       ],
     },
 )
