@@ -11,23 +11,21 @@
 #
 ##############################################################################
 """Image object
-
-$Id: Image.py 123341 2011-11-14 16:42:11Z yuppie $
 """
+
 from cgi import escape
 from cStringIO import StringIO
 from mimetools import choose_boundary
 import struct
 
+from AccessControl.class_init import InitializeClass
 from AccessControl.Permissions import change_images_and_files
 from AccessControl.Permissions import view_management_screens
 from AccessControl.Permissions import view as View
 from AccessControl.Permissions import ftp_access
 from AccessControl.Permissions import delete_objects
-from AccessControl.Role import RoleManager
 from AccessControl.SecurityInfo import ClassSecurityInfo
 from Acquisition import Implicit
-from App.class_init import InitializeClass
 from App.special_dtml import DTMLFile
 from DateTime.DateTime import DateTime
 from Persistence import Persistent
@@ -43,6 +41,7 @@ from zope.interface import implements
 
 from OFS.Cache import Cacheable
 from OFS.PropertyManager import PropertyManager
+from OFS.role import RoleManager
 from OFS.SimpleItem import Item_w__name__
 
 from zope.event import notify
@@ -119,10 +118,8 @@ class File(Persistent, Implicit, PropertyManager,
 
     manage_options=(
         (
-        {'label':'Edit', 'action':'manage_main',
-         'help':('OFSP','File_Edit.stx')},
-        {'label':'View', 'action':'',
-         'help':('OFSP','File_View.stx')},
+        {'label': 'Edit', 'action': 'manage_main'},
+        {'label': 'View', 'action': ''},
         )
         + PropertyManager.manage_options
         + RoleManager.manage_options
@@ -506,7 +503,7 @@ class File(Persistent, Implicit, PropertyManager,
 
     def _get_content_type(self, file, body, id, content_type=None):
         headers=getattr(file, 'headers', None)
-        if headers and headers.has_key('content-type'):
+        if headers and 'content-type' in headers:
             content_type=headers['content-type']
         else:
             if not isinstance(body, str): body=body.data
@@ -790,10 +787,8 @@ class Image(File):
                  )
 
     manage_options=(
-        ({'label':'Edit', 'action':'manage_main',
-         'help':('OFSP','Image_Edit.stx')},
-         {'label':'View', 'action':'view_image_or_file',
-         'help':('OFSP','Image_View.stx')},)
+        ({'label':'Edit', 'action':'manage_main'},
+         {'label':'View', 'action':'view_image_or_file'}, )
         + PropertyManager.manage_options
         + RoleManager.manage_options
         + Item_w__name__.manage_options
