@@ -51,7 +51,7 @@ class TestsOfBroken(unittest.TestCase):
 
         klass = Broken(self, None, ('some.python.module', 'MyClass'))
 
-        self.failUnless(issubclass(klass, BrokenClass))
+        self.assertTrue(issubclass(klass, BrokenClass))
         self.assertEqual(klass.__name__, 'MyClass')
         self.assertEqual(klass.__module__, 'some.python.module')
         self.assertEqual(klass.product_name, 'unknown')
@@ -62,7 +62,7 @@ class TestsOfBroken(unittest.TestCase):
 
         klass = Broken(self, None, ('Products.MyProduct.MyClass', 'MyClass'))
 
-        self.failUnless(issubclass(klass, BrokenClass))
+        self.assertTrue(issubclass(klass, BrokenClass))
         self.assertEqual(klass.__name__, 'MyClass')
         self.assertEqual(klass.__module__, 'Products.MyProduct.MyClass')
         self.assertEqual(klass.product_name, 'MyProduct')
@@ -74,8 +74,8 @@ class TestsOfBroken(unittest.TestCase):
 
         inst = Broken(self, OID, ('Products.MyProduct.MyClass', 'MyClass'))
 
-        self.failUnless(isinstance(inst, BrokenClass))
-        self.failUnless(inst._p_jar is self)
+        self.assertTrue(isinstance(inst, BrokenClass))
+        self.assertTrue(inst._p_jar is self)
         self.assertEqual(inst._p_oid, OID)
 
         klass = inst.__class__
@@ -129,7 +129,7 @@ class TestsIntegratedBroken(base.TestCase):
         # get new connection that will give access to broken object
         app = base.app()
         inst = aq_base(app.tr)
-        self.failUnless(isinstance(inst, BrokenClass))
+        self.assertTrue(isinstance(inst, BrokenClass))
         state = inst.__getstate__()
         self.assertEqual(state, {'id': 'tr'})
 
@@ -138,7 +138,7 @@ class TestsIntegratedBroken(base.TestCase):
         transaction.commit()
         # check that object is not left over
         app = base.app()
-        self.failIf('tr' in app.objectIds())
+        self.assertFalse('tr' in app.objectIds())
 
 
 def test_suite():
@@ -150,6 +150,3 @@ def test_suite():
 
 def main():
     unittest.main(defaultTest='test_suite')
-
-if __name__ == '__main__':
-    main()
