@@ -12,25 +12,13 @@
 #
 ##############################################################################
 """Initialize the Five product
-
-$Id: __init__.py 110405 2010-04-01 16:13:15Z tseaver $
 """
-from Products.Five import zcml
 
 # public API provided by Five
 # usage: from Products.Five import <something>
 from Products.Five.browser import BrowserView
 from Products.Five.skin.standardmacros import StandardMacros
 
-# load the site's ZCML tree (usually site.zcml) upon product
-# initialization
-def initialize(context):
-    from zope.schema.vocabulary import setVocabularyRegistry
-    from Products.Five.schema import Zope2VocabularyRegistry
-
-    zcml.load_site()
-    setVocabularyRegistry(Zope2VocabularyRegistry())
-
 # some convenience methods/decorators
 
 def fivemethod(func):
