@@ -11,8 +11,3 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Python
-
-$Id: pythonproduct1.py 110405 2010-04-01 16:13:15Z tseaver $
-"""
-
