@@ -24,24 +24,25 @@ from urllib import quote
 from urlparse import urlparse
 from urlparse import urlunparse
 
-from AccessControl.Owned import Owned
-from AccessControl.Role import RoleManager
+from AccessControl.class_init import InitializeClass
 from AccessControl.SecurityInfo import ClassSecurityInfo
 from Acquisition import Implicit
 from Acquisition import aq_parent
 from Acquisition import aq_inner
-from App.class_init import InitializeClass
 from App.Management import Tabs
 from App.special_dtml import DTMLFile
 from Persistence import Persistent
 from persistent import TimeStamp
+from OFS.owner import Owned
+from OFS.role import RoleManager
 from OFS.SimpleItem import Item
 from ZPublisher.BeforeTraverse import registerBeforeTraverse
 from ZPublisher.BeforeTraverse import unregisterBeforeTraverse
 from ZPublisher.BeforeTraverse import queryBeforeTraverse
 from zope.interface import implements
 
-from Products.Sessions.SessionInterfaces import IBrowserIdManager
+from Products.Sessions.interfaces import IBrowserIdManager
+from Products.Sessions.interfaces import BrowserIdManagerErr
 from Products.Sessions.SessionPermissions import ACCESS_CONTENTS_PERM
 from Products.Sessions.SessionPermissions import CHANGE_IDMGR_PERM
 from Products.Sessions.SessionPermissions import MGMT_SCREEN_PERM
@@ -102,9 +103,6 @@ def constructBrowserIdManager(
     if REQUEST is not None:
         return self.manage_main(self, REQUEST, update_menu=1)
     
-class BrowserIdManagerErr(ValueError): # BBB
-    pass
-    
 class BrowserIdManager(Item, Persistent, Implicit, RoleManager, Owned, Tabs):
     """ browser id management class
     """
@@ -291,7 +289,7 @@ class BrowserIdManager(Item, Persistent, Implicit, RoleManager, Owned, Tabs):
 
         o Enforce "valid" values.
         """
-        if not (type(k) is type('') and k and not badidnamecharsin(k)):
+        if not (type(k) is str and k and not badidnamecharsin(k)):
             raise BrowserIdManagerErr(
                             'Bad id name string %s' % escape(repr(k)))
         self.browserid_name = k
@@ -315,7 +313,7 @@ class BrowserIdManager(Item, Persistent, Implicit, RoleManager, Owned, Tabs):
     security.declareProtected(CHANGE_IDMGR_PERM, 'setCookiePath')
     def setCookiePath(self, path=''):
         """ sets cookie 'path' element for id cookie """
-        if not (type(path) is type('') and not badcookiecharsin(path)):
+        if not (type(path) is str and not badcookiecharsin(path)):
             raise BrowserIdManagerErr(
                             'Bad cookie path %s' % escape(repr(path)))
         self.cookie_path = path
@@ -342,7 +340,7 @@ class BrowserIdManager(Item, Persistent, Implicit, RoleManager, Owned, Tabs):
     security.declareProtected(CHANGE_IDMGR_PERM, 'setCookieDomain')
     def setCookieDomain(self, domain):
         """ sets cookie 'domain' element for id cookie """
-        if type(domain) is not type(''):
+        if type(domain) is not str:
             raise BrowserIdManagerErr(
                             'Cookie domain must be string: %s'
                                 % escape(repr(domain)))
