@@ -7,24 +7,19 @@
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
-# FOR A PARTICULAR PURPOSE
+# FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
 """Package of template utility classes and functions.
-
-$Id: __init__.py 110405 2010-04-01 16:13:15Z tseaver $
 """
-# BBB 2005/05/01 -- to be removed after 12 months
-import zope.deferredimport
-zope.deferredimport.define(
-    Iterator = 'ZTUtils.Iterator:Iterator'
-    )
+from AccessControl.SecurityInfo import ModuleSecurityInfo
+security = ModuleSecurityInfo('ZTUtils')
 
+security.declarePublic('encodeExpansion', 'decodeExpansion', 'a2b', 'b2a')
 from Tree import encodeExpansion, decodeExpansion, a2b, b2a
-from SimpleTree import SimpleTreeMaker
-
-__allow_access_to_unprotected_subobjects__ = 1
-__roles__ = None
 
+security.declarePublic('Batch', 'TreeMaker', 'SimpleTreeMaker', 'LazyFilter')
 from ZTUtils.Zope import Batch, TreeMaker, SimpleTreeMaker, LazyFilter
+
+security.declarePublic('url_query', 'make_query', 'make_hidden_input')
 from ZTUtils.Zope import url_query, make_query, make_hidden_input
