@@ -11,8 +11,6 @@
 #
 ##############################################################################
 """WebDAV support - resource objects.
-
-$Id: Resource.py 110405 2010-04-01 16:13:15Z tseaver $
 """
 
 import mimetypes
@@ -23,6 +21,7 @@ from urllib import unquote
 
 from AccessControl import getSecurityManager
 from AccessControl import ClassSecurityInfo
+from AccessControl.class_init import InitializeClass
 from AccessControl.Permissions import delete_objects
 from AccessControl.Permissions import manage_properties
 from AccessControl.Permissions import view as View
@@ -32,7 +31,6 @@ from AccessControl.Permissions import webdav_access
 from Acquisition import aq_base
 from Acquisition import aq_inner
 from Acquisition import aq_parent
-from App.class_init import InitializeClass
 from ExtensionClass import Base
 from OFS.event import ObjectClonedEvent
 from OFS.event import ObjectWillBeMovedEvent
@@ -151,7 +149,6 @@ class Resource(Base, LockableItem):
         # the final part of the URL  (ie '/a/b/foo.html' becomes '/a/b/')
         if col: url = url[:url.rfind('/')+1]
 
-        havetag = lambda x, self=self: self.wl_hasLock(x)
         found = 0; resourcetagged = 0
         taglist = IfParser(ifhdr)
         for tag in taglist:
@@ -159,7 +156,7 @@ class Resource(Base, LockableItem):
             if not tag.resource:
                 # There's no resource (url) with this tag
                 tag_list = map(tokenFinder, tag.list)
-                wehave = filter(havetag, tag_list)
+                wehave = [t for t in tag_list if self.wl_hasLock(t)]
 
                 if not wehave: continue
                 if tag.NOTTED: continue
@@ -170,7 +167,7 @@ class Resource(Base, LockableItem):
             elif urlbase(tag.resource) == url:
                 resourcetagged = 1
                 tag_list = map(tokenFinder, tag.list)
-                wehave = filter(havetag, tag_list)
+                wehave = [t for t in tag_list if self.wl_hasLock(t)]
 
                 if not wehave: continue
                 if tag.NOTTED: continue
