@@ -97,10 +97,10 @@ committed or aborted.  The methods are passed the current Transaction
 as their only argument.
 """
 
+import binascii
 import logging
 import sys
 import thread
-import warnings
 import weakref
 import traceback
 from cStringIO import StringIO
@@ -242,6 +242,13 @@ class Transaction(object):
                 transaction_savepoint._savepoints.append(
                     datamanager_savepoint)
 
+    def _unjoin(self, resource):
+        # Leave a transaction because a savepoint was rolled back on a resource
+        # that joined later.
+
+        # Don't use remove.  We don't want to assume anything about __eq__.
+        self._resources = [r for r in self._resources if r is not resource]
+
     def savepoint(self, optimistic=False):
         if self.status is Status.COMMITFAILED:
             self._prior_operation_failed() # doesn't return, it raises
@@ -322,9 +329,15 @@ class Transaction(object):
             self._commitResources()
             self.status = Status.COMMITTED
         except:
-            t, v, tb = self._saveAndGetCommitishError()
-            self._callAfterCommitHooks(status=False)
-            raise t, v, tb
+            t = None
+            v = None
+            tb = None
+            try:
+                t, v, tb = self._saveAndGetCommitishError()
+                self._callAfterCommitHooks(status=False)
+                raise t, v, tb
+            finally:
+                del t, v, tb
         else:
             if self._manager:
                 self._manager.free(self)
@@ -336,18 +349,32 @@ class Transaction(object):
         self.status = Status.COMMITFAILED
         # Save the traceback for TransactionFailedError.
         ft = self._failure_traceback = StringIO()
-        t, v, tb = sys.exc_info()
-        # Record how we got into commit().
-        traceback.print_stack(sys._getframe(1), None, ft)
-        # Append the stack entries from here down to the exception.
-        traceback.print_tb(tb, None, ft)
-        # Append the exception type and value.
-        ft.writelines(traceback.format_exception_only(t, v))
-        return t, v, tb
+        t = None
+        v = None
+        tb = None
+        try:
+            t, v, tb = sys.exc_info()
+            # Record how we got into commit().
+            traceback.print_stack(sys._getframe(1), None, ft)
+            # Append the stack entries from here down to the exception.
+            traceback.print_tb(tb, None, ft)
+            # Append the exception type and value.
+            ft.writelines(traceback.format_exception_only(t, v))
+            return t, v, tb
+        finally:
+            del t, v, tb
+        
 
     def _saveAndRaiseCommitishError(self):
-        t, v, tb = self._saveAndGetCommitishError()
-        raise t, v, tb
+        t = None
+        v = None
+        tb = None
+        try:
+            t, v, tb = self._saveAndGetCommitishError()
+            raise t, v, tb
+        finally:
+            del t, v, tb
+            
 
     def getBeforeCommitHooks(self):
         return iter(self._before_commit)
@@ -435,10 +462,13 @@ class Transaction(object):
             # to revert the changes in each of the resource managers.
             t, v, tb = sys.exc_info()
             try:
-                self._cleanup(L)
+                try:
+                    self._cleanup(L)
+                finally:
+                    self._synchronizers.map(lambda s: s.afterCompletion(self))
+                raise t, v, tb
             finally:
-                self._synchronizers.map(lambda s: s.afterCompletion(self))
-            raise t, v, tb
+                del t, v, tb
 
     def _cleanup(self, L):
         # Called when an exception occurs during tpc_vote or tpc_finish.
@@ -462,25 +492,32 @@ class Transaction(object):
 
         self._synchronizers.map(lambda s: s.beforeCompletion(self))
 
-        tb = None
-        for rm in self._resources:
-            try:
-                rm.abort(self)
-            except:
-                if tb is None:
-                    t, v, tb = sys.exc_info()
-                self.log.error("Failed to abort resource manager: %s",
-                               rm, exc_info=sys.exc_info())
+        try:
 
-        if self._manager:
-            self._manager.free(self)
+            t = None
+            v = None
+            tb = None
+            
+            for rm in self._resources:
+                try:
+                    rm.abort(self)
+                except:
+                    if tb is None:
+                        t, v, tb = sys.exc_info()
+                    self.log.error("Failed to abort resource manager: %s",
+                                   rm, exc_info=sys.exc_info())
 
-        self._synchronizers.map(lambda s: s.afterCompletion(self))
+            if self._manager:
+                self._manager.free(self)
 
-        self.log.debug("abort")
+            self._synchronizers.map(lambda s: s.afterCompletion(self))
 
-        if tb is not None:
-            raise t, v, tb
+            self.log.debug("abort")
+
+            if tb is not None:
+                raise t, v, tb
+        finally:
+            del t, v, tb
 
     def note(self, text):
         text = text.strip()
@@ -535,19 +572,25 @@ class MultiObjectResourceAdapter(object):
         self.manager.tpc_vote(txn)
 
     def abort(self, txn):
+        t = None
+        v = None
         tb = None
-        for o in self.objects:
-            try:
-                self.manager.abort(o, txn)
-            except:
-                # Capture the first exception and re-raise it after
-                # aborting all the other objects.
-                if tb is None:
-                    t, v, tb = sys.exc_info()
-                txn.log.error("Failed to abort object: %s",
-                              object_hint(o), exc_info=sys.exc_info())
-        if tb is not None:
-            raise t, v, tb
+        try:
+            for o in self.objects:
+                try:
+                    self.manager.abort(o, txn)
+                except:
+                    # Capture the first exception and re-raise it after
+                    # aborting all the other objects.
+                    if tb is None:
+                        t, v, tb = sys.exc_info()
+                    txn.log.error("Failed to abort object: %s",
+                                  object_hint(o), exc_info=sys.exc_info())
+
+            if tb is not None:
+                raise t, v, tb
+        finally:
+            del t, v, tb
 
 def rm_cmp(rm1, rm2):
     return cmp(rm1.sortKey(), rm2.sortKey())
@@ -569,7 +612,7 @@ def object_hint(o):
 def oid_repr(oid):
     if isinstance(oid, str) and len(oid) == 8:
         # Convert to hex and strip leading zeroes.
-        as_hex = hexlify(oid).lstrip('0')
+        as_hex = binascii.hexlify(oid).lstrip('0')
         # Ensure two characters per input byte.
         if len(as_hex) & 1:
             as_hex = '0' + as_hex
@@ -669,6 +712,7 @@ class AbortSavepoint:
 
     def rollback(self):
         self.datamanager.abort(self.transaction)
+        self.transaction._unjoin(self.datamanager)
 
 class NoRollbackSavepoint:
 
