@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Corporation and Contributors.
+# Copyright (c) 2005 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,32 +12,38 @@
 #
 ##############################################################################
 """Component Architecture configuration handlers
-
-$Id: zcml.py 100192 2009-05-21 13:22:14Z faassen $
 """
 __docformat__ = "reStructuredText"
 
 import warnings
 import zope.component
+import zope.configuration.fields
 import zope.interface
 import zope.schema
-import zope.configuration.fields
-from zope.configuration.exceptions import ConfigurationError
-import zope.security.zcml
+
 from zope.component.interface import provideInterface
-from zope.proxy import ProxyBase, getProxiedObject
-from zope.security.proxy import Proxy
-from zope.security.checker import InterfaceChecker, CheckerPublic, Checker
-from zope.security.adapter import LocatingTrustedAdapterFactory
-from zope.security.adapter import LocatingUntrustedAdapterFactory
-from zope.security.adapter import TrustedAdapterFactory
+from zope.configuration.exceptions import ConfigurationError
 from zope.i18nmessageid import MessageFactory
+
+try:
+    from zope.component.security import _checker, proxify, protectedFactory, \
+        securityAdapterFactory
+    from zope.security.zcml import Permission
+except ImportError:
+    SECURITY_SUPPORT = False
+    from zope.schema import TextLine as Permission
+else:
+    SECURITY_SUPPORT = True
+
 _ = MessageFactory('zope')
 
-PublicPermission = 'zope.Public'
+def check_security_support():
+    if not SECURITY_SUPPORT:
+        raise ConfigurationError("security proxied components are not "
+            "supported because zope.security is not available")
 
 def handler(methodName, *args, **kwargs):
-    method = getattr(zope.component.getGlobalSiteManager(), methodName)
+    method = getattr(zope.component.getSiteManager(), methodName)
     method(*args, **kwargs)
 
 class IBasicComponentInformation(zope.interface.Interface):
@@ -51,7 +57,7 @@ class IBasicComponentInformation(zope.interface.Interface):
         required=False,
         )
 
-    permission = zope.security.zcml.Permission(
+    permission = Permission(
         title=_("Permission"),
         description=_("Permission required to use this component."),
         required=False,
@@ -96,7 +102,7 @@ class IAdapterDirective(zope.interface.Interface):
           ),
         )
 
-    permission = zope.security.zcml.Permission(
+    permission = Permission(
         title=_("Permission"),
         description=_("This adapter is only available, if the principal"
                       " has this permission."),
@@ -147,20 +153,6 @@ def _rolledUpFactory(factories):
     factory.factory = factories[0]
     return factory
 
-def _protectedFactory(original_factory, checker):
-    # This has to be named 'factory', aparently, so as not to confuse
-    # apidoc :(
-    def factory(*args):
-        ob = original_factory(*args)
-        try:
-            ob.__Security_checker__ = checker
-        except AttributeError:
-            ob = Proxy(ob, checker)
-
-        return ob
-    factory.factory = original_factory
-    return factory
-
 def adapter(_context, factory, provides=None, for_=None, permission=None,
             name='', trusted=False, locate=False):
 
@@ -195,20 +187,13 @@ def adapter(_context, factory, provides=None, for_=None, permission=None,
         factory = _rolledUpFactory(factories)
 
     if permission is not None:
-        if permission == PublicPermission:
-            permission = CheckerPublic
-        checker = InterfaceChecker(provides, permission)
-        factory = _protectedFactory(factory, checker)
+        check_security_support()
+        factory = protectedFactory(factory, provides, permission)
 
     # invoke custom adapter factories
-    if locate or (permission is not None and permission is not CheckerPublic):
-        if trusted:
-            factory = LocatingTrustedAdapterFactory(factory)
-        else:
-            factory = LocatingUntrustedAdapterFactory(factory)
-    else:
-        if trusted:
-            factory = TrustedAdapterFactory(factory)
+    if locate or permission is not None or trusted:
+        check_security_support()
+        factory = securityAdapterFactory(factory, permission, locate, trusted)
 
     _context.action(
         discriminator = ('adapter', for_, provides, name),
@@ -263,7 +248,7 @@ class ISubscriberDirective(zope.interface.Interface):
           ),
         )
 
-    permission = zope.security.zcml.Permission(
+    permission = Permission(
         title=_("Permission"),
         description=_("This subscriber is only available, if the"
                       " principal has this permission."),
@@ -319,22 +304,15 @@ def subscriber(_context, for_=None, factory=None, handler=None, provides=None,
                             "determine what the factory (or handler) adapts.")
 
     if permission is not None:
-        if permission == PublicPermission:
-            permission = CheckerPublic
-        checker = InterfaceChecker(provides, permission)
-        factory = _protectedFactory(factory, checker)
+        check_security_support()
+        factory = protectedFactory(factory, provides, permission)
 
     for_ = tuple(for_)
 
     # invoke custom adapter factories
-    if locate or (permission is not None and permission is not CheckerPublic):
-        if trusted:
-            factory = LocatingTrustedAdapterFactory(factory)
-        else:
-            factory = LocatingUntrustedAdapterFactory(factory)
-    else:
-        if trusted:
-            factory = TrustedAdapterFactory(factory)
+    if locate or permission is not None or trusted:
+        check_security_support()
+        factory = securityAdapterFactory(factory, permission, locate, trusted)
 
     if handler is not None:
         _context.action(
@@ -383,24 +361,6 @@ class IUtilityDirective(IBasicComponentInformation):
         required=False,
         )
 
-class PermissionProxy(ProxyBase):
-
-    __slots__ = ('__Security_checker__', )
-
-    def __providedBy__(self):
-        return zope.interface.providedBy(getProxiedObject(self))
-    __providedBy__ = property(__providedBy__)
-
-def proxify(ob, checker):
-    """Try to get the object proxied with the `checker`, but not too soon
-
-    We really don't want to proxy the object unless we need to.
-    """
-
-    ob = PermissionProxy(ob)
-    ob.__Security_checker__ = checker
-    return ob
-
 def utility(_context, provides=None, component=None, factory=None,
             permission=None, name=''):
     if factory and component:
@@ -417,11 +377,8 @@ def utility(_context, provides=None, component=None, factory=None,
             raise TypeError("Missing 'provides' attribute")
 
     if permission is not None:
-        if permission == PublicPermission:
-            permission = CheckerPublic
-        checker = InterfaceChecker(provides, permission)
-
-        component = proxify(component, checker)
+        check_security_support()
+        component = proxify(component, provides=provides, permission=permission)
 
     _context.action(
         discriminator = ('utility', provides, name),
@@ -475,7 +432,7 @@ class IBasicViewInformation(zope.interface.Interface):
           ),
         )
 
-    permission = zope.security.zcml.Permission(
+    permission = Permission(
         title=_("Permission"),
         description=_("The permission needed to use the view."),
         required=False,
@@ -572,7 +529,8 @@ def view(_context, factory, type, name, for_, layer=None,
     if not factory:
         raise ConfigurationError("No view factory specified.")
 
-    if permission:
+    if permission is not None:
+        check_security_support()
 
         checker = _checker(_context, permission,
                            allowed_interface, allowed_attributes)
@@ -684,7 +642,9 @@ def resource(_context, factory, type, name, layer=None,
             "allowed_attributes"
             )
 
-    if permission:
+    if permission is not None:
+        check_security_support()
+
         checker = _checker(_context, permission,
                            allowed_interface, allowed_attributes)
 
@@ -716,22 +676,3 @@ def resource(_context, factory, type, name, layer=None,
         callable = provideInterface,
         args = (provides.__module__ + '.' + provides.__name__, type)
                )
-
-def _checker(_context, permission, allowed_interface, allowed_attributes):
-    if (not allowed_attributes) and (not allowed_interface):
-        allowed_attributes = ["__call__"]
-
-    if permission == PublicPermission:
-        permission = CheckerPublic
-
-    require={}
-    if allowed_attributes:
-        for name in allowed_attributes:
-            require[name] = permission
-    if allowed_interface:
-        for i in allowed_interface:
-            for name in i.names(all=True):
-                require[name] = permission
-
-    checker = Checker(require)
-    return checker
