@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2003 Zope Corporation and Contributors.
+# Copyright (c) 2003 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,13 +12,11 @@
 #
 ##############################################################################
 """Test XML configuration (ZCML) machinery.
-
-$Id: test_xmlconfig.py 97297 2009-02-26 13:25:10Z nadako $
 """
 import unittest
 import os
 import re
-from zope.testing.doctestunit import DocTestSuite, DocFileSuite
+from doctest import DocTestSuite, DocFileSuite
 from zope.testing import renormalizing
 from zope.configuration import xmlconfig, config
 from zope.configuration.tests.samplepackage import foo
