@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001, 2002, 2003 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002, 2003 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -16,8 +16,6 @@
 Note, for a detailed description of the way that conflicting
 configuration actions are resolved, see the detailed example in
 test_includeOverrides in tests/test_xmlconfig.py
-
-$Id: xmlconfig.py 97385 2009-02-28 17:09:17Z nadako $
 """
 __docformat__ = 'restructuredtext'
 
@@ -209,7 +207,11 @@ class ConfigurationHandler(ContentHandler):
 
         data = {}
         for (ns, aname), value in attrs.items():
-            if ns is None:
+            # NB: even though on CPython, 'ns' will be ``None`` always,
+            # do not change the below to "if ns is None" because Jython's
+            # sax parser generates attrs that have empty strings for
+            # the namepace instead of ``None``.
+            if not ns:
                 aname = str(aname)
                 data[aname] = value
             if (ns, aname) == ZCML_CONDITION:
