@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 ##############################################################################
 #
-# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -13,11 +13,9 @@
 #
 ##############################################################################
 """HTTP Publisher Tests
-
-$Id: test_http.py 96537 2009-02-14 15:13:58Z benji_york $
 """
-
 import unittest
+import doctest
 import zope.testing
 
 
@@ -27,7 +25,7 @@ def cleanUp(test):
 
 def test_suite():
     return unittest.TestSuite(
-        zope.testing.doctest.DocFileSuite('../skinnable.txt',
+        doctest.DocFileSuite('../skinnable.txt',
             setUp=cleanUp, tearDown=cleanUp))
 
 
