@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 ##############################################################################
-# Copyright (c) 2002 Zope Corporation and Contributors.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,8 +12,6 @@
 #
 ##############################################################################
 """Schema Fields
-
-$Id: _field.py 98319 2009-03-23 12:51:31Z zagy $
 """
 
 __docformat__ = 'restructuredtext'
@@ -21,11 +19,9 @@ __docformat__ = 'restructuredtext'
 import re
 import decimal
 from datetime import datetime, date, timedelta, time
-import sys
-
 from zope.event import notify
 
-from zope.interface import classImplements, implements
+from zope.interface import classImplements, implements, Interface
 from zope.interface.interfaces import IInterface, IMethod
 
 from zope.schema.interfaces import IField
@@ -58,10 +54,10 @@ from zope.schema.vocabulary import SimpleVocabulary
 
 
 # Fix up bootstrap field types
-Field.title       = FieldProperty(IField['title'])
+Field.title = FieldProperty(IField['title'])
 Field.description = FieldProperty(IField['description'])
-Field.required    = FieldProperty(IField['required'])
-Field.readonly    = FieldProperty(IField['readonly'])
+Field.required = FieldProperty(IField['required'])
+Field.readonly = FieldProperty(IField['readonly'])
 # Default is already taken care of
 classImplements(Field, IField)
 
@@ -75,11 +71,13 @@ classImplements(Bool, IBool)
 classImplements(Bool, IFromUnicode)
 classImplements(Int, IInt)
 
+
 class SourceText(Text):
     __doc__ = ISourceText.__doc__
     implements(ISourceText)
     _type = unicode
 
+
 class Bytes(MinMaxLen, Field):
     __doc__ = IBytes.__doc__
     implements(IBytes, IFromUnicode)
@@ -102,6 +100,7 @@ class Bytes(MinMaxLen, Field):
         self.validate(v)
         return v
 
+
 class ASCII(Bytes):
     __doc__ = IASCII.__doc__
     implements(IASCII)
@@ -132,6 +131,7 @@ class ASCII(Bytes):
         if not max(map(ord, value)) < 128:
             raise InvalidValue
 
+
 class BytesLine(Bytes):
     """A Text field with no newlines."""
 
@@ -141,6 +141,7 @@ class BytesLine(Bytes):
         # TODO: we should probably use a more general definition of newlines
         return '\n' not in value
 
+
 class ASCIILine(ASCII):
     __doc__ = IASCIILine.__doc__
 
@@ -150,6 +151,7 @@ class ASCIILine(ASCII):
         # TODO: we should probably use a more general definition of newlines
         return '\n' not in value
 
+
 class Float(Orderable, Field):
     __doc__ = IFloat.__doc__
     implements(IFloat, IFromUnicode)
@@ -163,7 +165,7 @@ class Float(Orderable, Field):
         >>> f = Float()
         >>> f.fromUnicode("1.25")
         1.25
-        >>> f.fromUnicode("1.25.6")
+        >>> f.fromUnicode("1.25.6") #doctest: +IGNORE_EXCEPTION_DETAIL
         Traceback (most recent call last):
         ...
         ValueError: invalid literal for float(): 1.25.6
@@ -172,6 +174,7 @@ class Float(Orderable, Field):
         self.validate(v)
         return v
 
+
 class Decimal(Orderable, Field):
     __doc__ = IDecimal.__doc__
     implements(IDecimal, IFromUnicode)
@@ -200,6 +203,7 @@ class Decimal(Orderable, Field):
         self.validate(v)
         return v
 
+
 class Datetime(Orderable, Field):
     __doc__ = IDatetime.__doc__
     implements(IDatetime)
@@ -208,26 +212,30 @@ class Datetime(Orderable, Field):
     def __init__(self, *args, **kw):
         super(Datetime, self).__init__(*args, **kw)
 
+
 class Date(Orderable, Field):
     __doc__ = IDate.__doc__
     implements(IDate)
     _type = date
-    
+
     def _validate(self, value):
         super(Date, self)._validate(value)
         if isinstance(value, datetime):
-            raise WrongType(value, self._type)
+            raise WrongType(value, self._type, self.__name__)
+
 
 class Timedelta(Orderable, Field):
     __doc__ = ITimedelta.__doc__
     implements(ITimedelta)
     _type = timedelta
-    
+
+
 class Time(Orderable, Field):
     __doc__ = ITime.__doc__
     implements(ITime)
     _type = time
 
+
 class Choice(Field):
     """Choice fields can have a value found in a constant or dynamic set of
     values given by the field definition.
@@ -256,7 +264,7 @@ class Choice(Field):
         elif isinstance(vocabulary, (unicode, str)):
             self.vocabularyName = vocabulary
         else:
-            assert (ISource.providedBy(vocabulary) or 
+            assert (ISource.providedBy(vocabulary) or
                     IContextSourceBinder.providedBy(vocabulary))
             self.vocabulary = vocabulary
         # Before a default value is checked, it is validated. However, a
@@ -317,6 +325,7 @@ class Choice(Field):
         if value not in vocabulary:
             raise ConstraintNotSatisfied(value)
 
+
 class InterfaceField(Field):
     __doc__ = IInterfaceField.__doc__
     implements(IInterfaceField)
@@ -324,7 +333,8 @@ class InterfaceField(Field):
     def _validate(self, value):
         super(InterfaceField, self)._validate(value)
         if not IInterface.providedBy(value):
-            raise WrongType("An interface is required")
+            raise WrongType("An interface is required", value, self.__name__)
+
 
 def _validate_sequence(value_type, value, errors=None):
     """Validates a sequence value.
@@ -343,7 +353,7 @@ def _validate_sequence(value_type, value, errors=None):
 
             >>> errors = _validate_sequence(field, ('foo', u'bar', 1))
             >>> errors
-            [WrongType('foo', <type 'unicode'>), WrongType(1, <type 'unicode'>)]
+            [WrongType('foo', <type 'unicode'>, ''), WrongType(1, <type 'unicode'>, '')]
 
         The only valid value in the sequence is the second item. The others
         generated errors.
@@ -353,7 +363,7 @@ def _validate_sequence(value_type, value, errors=None):
 
         >>> errors = _validate_sequence(field, (2, u'baz'), errors)
         >>> errors
-        [WrongType('foo', <type 'unicode'>), WrongType(1, <type 'unicode'>), WrongType(2, <type 'unicode'>)]
+        [WrongType('foo', <type 'unicode'>, ''), WrongType(1, <type 'unicode'>, ''), WrongType(2, <type 'unicode'>, '')]
 
     """
     if errors is None:
@@ -367,6 +377,7 @@ def _validate_sequence(value_type, value, errors=None):
             errors.append(error)
     return errors
 
+
 def _validate_uniqueness(value):
     temp_values = []
     for item in value:
@@ -375,6 +386,7 @@ def _validate_uniqueness(value):
 
         temp_values.append(item)
 
+
 class AbstractCollection(MinMaxLen, Iterable):
     value_type = None
     unique = False
@@ -400,54 +412,82 @@ class AbstractCollection(MinMaxLen, Iterable):
         super(AbstractCollection, self)._validate(value)
         errors = _validate_sequence(self.value_type, value)
         if errors:
-            raise WrongContainedType(errors)
+            raise WrongContainedType(errors, self.__name__)
         if self.unique:
             _validate_uniqueness(value)
 
+
 class Tuple(AbstractCollection):
     """A field representing a Tuple."""
     implements(ITuple)
     _type = tuple
 
+
 class List(AbstractCollection):
     """A field representing a List."""
     implements(IList)
     _type = list
 
+
 class Set(AbstractCollection):
     """A field representing a set."""
     implements(ISet)
     _type = set
+
     def __init__(self, **kw):
         if 'unique' in kw: # set members are always unique
             raise TypeError(
                 "__init__() got an unexpected keyword argument 'unique'")
         super(Set, self).__init__(unique=True, **kw)
 
+
 class FrozenSet(AbstractCollection):
     implements(IFrozenSet)
     _type = frozenset
+
     def __init__(self, **kw):
         if 'unique' in kw: # set members are always unique
             raise TypeError(
                 "__init__() got an unexpected keyword argument 'unique'")
         super(FrozenSet, self).__init__(unique=True, **kw)
 
+
 def _validate_fields(schema, value, errors=None):
     if errors is None:
         errors = []
-    for name in schema.names(all=True):
-        if not IMethod.providedBy(schema[name]):
-            try:
-                attribute = schema[name]
-                if IField.providedBy(attribute):
-                    # validate attributes that are fields
-                    attribute.validate(getattr(value, name))
-            except ValidationError, error:
-                errors.append(error)
-            except AttributeError, error:
-                # property for the given name is not implemented
-                errors.append(SchemaNotFullyImplemented(error))
+    # Interface can be used as schema property for Object fields that plan to
+    # hold values of any type.
+    # Because Interface does not include any Attribute, it is obviously not
+    # worth looping on its methods and filter them all out.
+    if schema is Interface:
+        return errors
+    # if `value` is part of a cyclic graph, we need to break the cycle to avoid
+    # infinite recursion.
+    #
+    # (use volatile attribute to avoid persistency/conflicts)
+    if hasattr(value, '_v_schema_being_validated'):
+        return errors
+    # Mark the value as being validated.
+    value._v_schema_being_validated = True
+    # (If we have gotten here, we know that `value` provides an interface
+    # other than zope.interface.Interface;
+    # iow, we can rely on the fact that it is an instance
+    # that supports attribute assignment.)
+    try:
+        for name in schema.names(all=True):
+            if not IMethod.providedBy(schema[name]):
+                try:
+                    attribute = schema[name]
+                    if IField.providedBy(attribute):
+                        # validate attributes that are fields
+                        attribute.validate(getattr(value, name))
+                except ValidationError, error:
+                    errors.append(error)
+                except AttributeError, error:
+                    # property for the given name is not implemented
+                    errors.append(SchemaNotFullyImplemented(error))
+    finally:
+        delattr(value, '_v_schema_being_validated')
     return errors
 
 
@@ -472,7 +512,7 @@ class Object(Field):
         # check the value against schema
         errors = _validate_fields(self.schema, value)
         if errors:
-            raise WrongContainedType(errors)
+            raise WrongContainedType(errors, self.__name__)
 
     def set(self, object, value):
         # Announce that we're going to assign the value to the object.
@@ -485,6 +525,7 @@ class Object(Field):
         value = event.object
         super(Object, self).set(object, value)
 
+
 class BeforeObjectAssignedEvent(object):
     """An object is going to be assigned to an attribute on another object."""
 
@@ -495,11 +536,12 @@ class BeforeObjectAssignedEvent(object):
         self.name = name
         self.context = context
 
+
 class Dict(MinMaxLen, Iterable):
     """A field representing a Dict."""
     implements(IDict)
     _type = dict
-    key_type   = None
+    key_type = None
     value_type = None
 
     def __init__(self, key_type=None, value_type=None, **kw):
@@ -522,7 +564,7 @@ class Dict(MinMaxLen, Iterable):
             errors = _validate_sequence(self.key_type, value, errors)
 
             if errors:
-                raise WrongContainedType(errors)
+                raise WrongContainedType(errors, self.__name__)
 
         finally:
             errors = None
@@ -533,16 +575,18 @@ class Dict(MinMaxLen, Iterable):
         # binding value_type is necessary for choices with named vocabularies,
         # and possibly also for other fields.
         if clone.key_type is not None:
-           clone.key_type = clone.key_type.bind(object)
+            clone.key_type = clone.key_type.bind(object)
         if clone.value_type is not None:
-           clone.value_type = clone.value_type.bind(object)
+            clone.value_type = clone.value_type.bind(object)
         return clone
 
 
 _isuri = re.compile(
-    r"[a-zA-z0-9+.-]+:"   # scheme
-    r"\S*$"               # non space (should be pickier)
-    ).match
+    # scheme
+    r"[a-zA-z0-9+.-]+:"
+    # non space (should be pickier)
+    r"\S*$").match
+
 
 class URI(BytesLine):
     """URI schema field
@@ -587,10 +631,11 @@ class URI(BytesLine):
 
 
 _isdotted = re.compile(
-    r"([a-zA-Z][a-zA-z0-9_]*)"
-    r"([.][a-zA-Z][a-zA-z0-9_]*)*"
-    r"$" # use the whole line
-    ).match
+    r"([a-zA-Z][a-zA-Z0-9_]*)"
+    r"([.][a-zA-Z][a-zA-Z0-9_]*)*"
+    # use the whole line
+    r"$").match
+
 
 class Id(BytesLine):
     """Id field
