@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,8 +12,6 @@
 #
 ##############################################################################
 """Local Component Architecture
-
-$Id: __init__.py 95220 2009-01-27 15:45:34Z faassen $
 """
 
 from zope.site.site import (SiteManagerContainer, SiteManagementFolder,
@@ -21,5 +19,6 @@ from zope.site.site import (SiteManagerContainer, SiteManagementFolder,
 from zope.site.site import LocalSiteManager, changeSiteConfigurationAfterMove
 from zope.site.site import threadSiteSubscriber
 from zope.site.site import clearThreadSiteSubscriber
-from zope.site.next import getNextUtility, queryNextUtility
 
+# BBB
+from zope.component import getNextUtility, queryNextUtility
