@@ -34,8 +34,20 @@ class GetCookie(View):
                 self.request.cookies.items()))
 
 class SetCookie(View):
-    """Gets cookie value"""
+    """Sets cookie value"""
 
     def __call__(self):
         self.request.response.setCookie(
             **dict((str(k), str(v)) for k, v in self.request.form.items()))
+
+
+class SetStatus(View):
+    """Sets HTTP status"""
+
+    def __call__(self):
+        status = self.request.get('status')
+        if status:
+            self.request.response.setStatus(int(status))
+            return 'Just set a status of %s' % status
+        else:
+            return 'Everything fine'
